@@ -24,16 +24,16 @@ format_valuef <- function(digits) {
 print.gsmar <- function(x, ..., digits=2, summary_print=FALSE) {
   gsmar <- x
   stopifnot(digits >= 0 & digits %% 1 == 0)
-  if(summary_print == TRUE) check_data(gsmar)
+  if(summary_print) check_data(gsmar)
 
   # Help functions
   format_value <- format_valuef(digits)
   print_err <- function(val) {
-    if(summary_print == TRUE) cat(paste0(" (", format_value(val),")"))
+    if(summary_print) cat(paste0(" (", format_value(val),")"))
   }
   make_string <- function(n_spaces, val) paste0(c(rep(" ", n_spaces), paste0("(", format_value(val), ")")), collapse="")
   add_string <- function(const_spaces, val1, val2) {
-    if(summary_print == TRUE) {
+    if(summary_print) {
       err_string[length(err_string) + 1] <<- make_string(const_spaces + nchar(format_value(val1)) - nchar(format_value(val2)), val2)
     }
   }
@@ -45,6 +45,7 @@ print.gsmar <- function(x, ..., digits=2, summary_print=FALSE) {
   restricted <- gsmar$model$restricted
   constraints <- gsmar$model$constraints
   all_mu <- round(get_regime_means(gsmar), digits)
+  #all_vars <- round(get_regime_vars(gsmar), digits) uncomment to print regime variances
 
   if(gsmar$model$parametrization == "mean") {
     params <- change_parametrization(p=p, M=M, params=params, model=model, restricted=restricted,
@@ -57,12 +58,13 @@ print.gsmar <- function(x, ..., digits=2, summary_print=FALSE) {
   alphas <- pick_alphas(p=p, M=M, params=params, model=model, restricted=FALSE, constraints=NULL)
   dfs <- pick_dfs(p=p, M=M, params=params, model=model)
 
-  if(summary_print == TRUE) {
+  if(summary_print) {
     all_ar_roots <- get_ar_roots(gsmar)
     std_errors <- removeAllConstraints(p=p, M=M, params=gsmar$std_errors, model=model, restricted=restricted,
                                        constraints=constraints)
     pars_err <- pick_pars(p=p, M=M, params=std_errors, model=model, restricted=FALSE, constraints=NULL)
     alphas_err <- pick_alphas(p=p, M=M, params=std_errors, model=model, restricted=FALSE, constraints=NULL)
+    alphas_err[sum(M)] <- NA
     dfs_err <- pick_dfs(p=p, M=M, params=std_errors, model=model)
     if(gsmar$model$parametrization == "mean") {
       mu_err <- pick_phi0(p=p, M=M, params=std_errors, model=model, restricted=FALSE, constraints=NULL)
@@ -84,7 +86,7 @@ print.gsmar <- function(x, ..., digits=2, summary_print=FALSE) {
       ifelse(restricted, "AR parameters restricted,", "not restricted,"),
       ifelse(is.null(constraints), "no constraints", "linear constraints imposed"), "\n")
 
-  if(summary_print == TRUE) {
+  if(summary_print) {
     IC <- gsmar$IC
     cat(paste("\nlog-likelihood:", format_value(gsmar$loglik)), "\n")
     cat(paste("AIC: ", format_value(IC$AIC)), "\n")
@@ -109,13 +111,13 @@ print.gsmar <- function(x, ..., digits=2, summary_print=FALSE) {
     cat(paste("Regime", m))
     if(model == "G-StMAR") cat(paste0(" (", regime_type, " type)"))
 
-    if(summary_print == TRUE) cat(paste("\nModulus of poly roots:", paste0(format_value(all_ar_roots[[m]]), collapse=", ")))
+    if(summary_print) cat(paste("\nModulus of poly roots:", paste0(format_value(all_ar_roots[[m]]), collapse=", ")))
 
     cat(paste("\nMix weight:", format_value(alphas[m])))
     print_err(alphas_err[m])
-
     cat("\nReg mean:", format_value(all_mu[m]))
     print_err(mu_err[m])
+    #cat("\nReg var:", format_value(all_vars[m])) # Uncomment to print regime variances
     cat("\n")
 
     if(regime_type == "StMAR") {
@@ -146,10 +148,10 @@ print.gsmar <- function(x, ..., digits=2, summary_print=FALSE) {
       cat("[cond_sd]eps")
     }
     cat("\n")
-    if(summary_print == TRUE) cat(paste0(err_string, collapse=""), '\n')
+    if(summary_print) cat(paste0(err_string, collapse=""), '\n')
   }
 
-  if(summary_print == TRUE) {
+  if(summary_print) {
     um <- gsmar$uncond_moments
     cat("\nProcess mean:", format_value(um$uncond_mean), "\n")
     cat("Process var: ", format_value(um$uncond_var), "\n")
@@ -192,7 +194,7 @@ print.gsmarsum <- function(x, ..., digits) {
 #'
 #' @param x object of class \code{'gsmarpred'} generated by \code{predict.gsmar}.
 #' @param digits number of decimals to print
-#' @param ... currectly not used.
+#' @param ... currently not used.
 #' @examples
 #'  \donttest{
 #'  # GMAR-model
@@ -210,29 +212,29 @@ print.gsmarpred <- function(x, ..., digits=2) {
   format_value <- format_valuef(digits)
 
   if(gsmarpred$pred_type == "cond_mean") {
-    cat("One-step-ahead prediction by exact conditional mean, no confidence intervals\n")
+    cat("One-step-ahead prediction by exact conditional mean, no prediction intervals\n")
     cat("Forecast:", paste0(format_value(gsmarpred$pred), collapse=", "), "\n")
 
-  } else if(gsmarpred$ci_type == "none") {
-    cat(paste0("Prediction by ", gsmarpred$pred_type, ", no confidence intervals"), "\n")
+  } else if(gsmarpred$pi_type == "none") {
+    cat(paste0("Prediction by ", gsmarpred$pred_type, ", no prediction intervals"), "\n")
     cat(paste0("Forecast ", gsmarpred$n_ahead, " steps ahead, based on ", gsmarpred$n_simu, " simulations\n"))
     print(data.frame(pred=gsmarpred$pred))
 
   } else {
-    cat(paste0("Prediction by ", gsmarpred$pred_type, ", ", gsmarpred$ci_type,
-               " confidence intervals with levels ", paste(gsmarpred$ci, collapse=", "), ""), "\n")
+    cat(paste0("Prediction by ", gsmarpred$pred_type, ", ", gsmarpred$pi_type,
+               " prediction intervals with levels ", paste(gsmarpred$pi, collapse=", "), ""), "\n")
     cat(paste0("Forecast ", gsmarpred$n_ahead, " steps ahead, based on ", gsmarpred$nsimu, " simulations\n"))
 
     cat("\n")
     q <- gsmarpred$q
-    conf_ints <- gsmarpred$conf_ints
+    pred_ints <- gsmarpred$pred_ints
     pred_type <- gsmarpred$pred_type
-    df <- as.data.frame(lapply(1:ncol(conf_ints), function(i1) format_value(conf_ints[,i1])))
+    df <- as.data.frame(lapply(1:ncol(pred_ints), function(i1) format_value(pred_ints[,i1])))
     names(df) <- q
     df[, pred_type] <- format_value(gsmarpred$pred)
-    if(gsmarpred$ci_type == "two-sided") {
+    if(gsmarpred$pi_type == "two-sided") {
       new_order <- as.character(c(q[1:(length(q)/2)], pred_type, q[(length(q)/2 + 1):length(q)]))
-    } else if(gsmarpred$ci_type == "upper") {
+    } else if(gsmarpred$pi_type == "upper") {
        new_order <- as.character(c(pred_type, q))
      } else {
       new_order <- names(df)
