@@ -197,3 +197,50 @@ test_that("get_ar_roots works correctly", {
   expect_equal(get_ar_roots(stmar23)[[2]], c(3.756722, 29.576611), tolerance=1e-5)
   expect_equal(get_ar_roots(gstmar13r)[[3]], 1.25, tolerance=1e-5)
 })
+
+pars11t <- c(1, 0.9, 1, 10)
+pars12t <- c(2, 0.9, 0.1, 0.8, 0.5, 0.5, 0.4, 12, 30)
+pars23t <- c(0.1, 0.1, 0.1, 0.1, 0.2, 0.5, 0.5, 0.2, 0.3, 0.3, 0.3, 0.3, 0.8, 0.05, 11, 12, 13)
+pars12tr <- c(0.1, 0.2, 0.9, 0.1, 0.2, 0.6, 14, 12)
+pars23tr <- c(0.1, 0.3, 0.4, -0.4, 0.3, 1, 2, 3, 0.5, 0.1, 1000, 112, 130)
+
+R1 <- matrix(c(1, 0, 0, 0, 0, 1), ncol=2)
+R2 <- diag(1, ncol=3, nrow=3)
+R3 <- matrix(c(0.5, 0.5), ncol=1)
+
+pars32tc <- c(1, 0.1, -0.1, 1, 2, 0.2, -0.2, 2, 0.6, 11, 12) #constraints=list(R1, R1)
+pars33tc <- c(1, 0.1, 0.1, 0.1, 1, 2, 0.2, 0.2, 0.2, 2, 3, 0.3, -0.3, 3, 0.3, 0.4, 13, 12, 11) #  constraints=list(R2, R2, R1)
+pars22tcr <- c(1, 2, 0.8, 1, 2, 0.7, 11, 12) # restricted=TRUE, constraints=R3
+pars21tcr <- c(1, 0.1, 1, 10) # restricted=TRUE, constraints=R3
+
+
+test_that("stmarpars_to_gstmar works correctly", {
+  expect_equal(stmarpars_to_gstmar(1, 1, pars11t, maxdf=4)$M, c(1, 0))
+  expect_equal(stmarpars_to_gstmar(1, 1, pars11t, maxdf=4)$reg_order, 1)
+  expect_equal(stmarpars_to_gstmar(1, 1, pars11t, maxdf=4)$params, c(1, 0.9, 1))
+  expect_equal(stmarpars_to_gstmar(1, 2, pars12t, maxdf=12)$M, c(1, 1))
+  expect_equal(stmarpars_to_gstmar(1, 2, pars12t, maxdf=12)$reg_order, c(2, 1))
+  expect_equal(stmarpars_to_gstmar(1, 2, pars12t, maxdf=12)$params, c(0.8, 0.5, 0.5, 2, 0.9, 0.1, 0.6, 12))
+  expect_equal(stmarpars_to_gstmar(2, 3, pars23t, maxdf=11)$M, c(2, 1))
+  expect_equal(stmarpars_to_gstmar(2, 3, pars23t, maxdf=11)$reg_order, c(3, 2, 1))
+  expect_equal(stmarpars_to_gstmar(2, 3, pars23t, maxdf=11)$params, c(0.3, 0.3, 0.3, 0.3, 0.2, 0.5, 0.5, 0.2, 0.1, 0.1, 0.1, 0.1, 0.15, 0.05, 11))
+  expect_equal(stmarpars_to_gstmar(1, 2, pars12tr, restricted=TRUE, maxdf=13)$M, c(1, 1))
+  expect_equal(stmarpars_to_gstmar(1, 2, pars12tr, restricted=TRUE, maxdf=13)$reg_order, c(1, 2))
+  expect_equal(stmarpars_to_gstmar(1, 2, pars12tr, restricted=TRUE, maxdf=13)$params, c(0.1, 0.2, 0.9, 0.1, 0.2, 0.6, 12))
+  expect_equal(stmarpars_to_gstmar(2, 3, pars23tr, restricted=TRUE, maxdf=120)$M, c(2, 1))
+  expect_equal(stmarpars_to_gstmar(2, 3, pars23tr, restricted=TRUE, maxdf=120)$reg_order, c(1, 3, 2))
+  expect_equal(stmarpars_to_gstmar(2, 3, pars23tr, restricted=TRUE, maxdf=120)$params, c(0.1, 0.4, 0.3, -0.4, 0.3, 1, 3, 2, 0.5, 0.4, 112))
+  expect_equal(stmarpars_to_gstmar(3, 2, pars32tc, constraints=list(R1, R1), maxdf=11)$M, c(1, 1))
+  expect_equal(stmarpars_to_gstmar(3, 2, pars32tc, constraints=list(R1, R1), maxdf=11)$reg_order, c(2, 1))
+  expect_equal(stmarpars_to_gstmar(3, 2, pars32tc, constraints=list(R1, R1), maxdf=11)$params, c(2, 0.2, -0.2, 2, 1, 0.1, -0.1, 1, 0.4, 11))
+  expect_equal(stmarpars_to_gstmar(3, 3, pars33tc, constraints=list(R2, R2, R1), maxdf=11)$M, c(2, 1))
+  expect_equal(stmarpars_to_gstmar(3, 3, pars33tc, constraints=list(R2, R2, R1), maxdf=11)$reg_order, c(2, 1, 3))
+  expect_equal(stmarpars_to_gstmar(3, 3, pars33tc, constraints=list(R2, R2, R1), maxdf=11)$params,
+               c(2, 0.2, 0.2, 0.2, 2, 1, 0.1, 0.1, 0.1, 1, 3, 0.3, -0.3, 3, 0.4, 0.3, 11))
+  expect_equal(stmarpars_to_gstmar(2, 2, pars22tcr, restricted=TRUE, constraints=R3, maxdf=11)$M, c(1, 1))
+  expect_equal(stmarpars_to_gstmar(2, 2, pars22tcr, restricted=TRUE, constraints=R3, maxdf=11)$reg_order, c(2, 1))
+  expect_equal(stmarpars_to_gstmar(2, 2, pars22tcr, restricted=TRUE, constraints=R3, maxdf=11)$params, c(2, 1, 0.8, 2, 1, 0.3, 11))
+  expect_equal(stmarpars_to_gstmar(2, 1, pars21tcr, restricted=TRUE, constraints=R3, maxdf=4)$M, c(1, 0))
+  expect_equal(stmarpars_to_gstmar(2, 1, pars21tcr, restricted=TRUE, constraints=R3, maxdf=4)$reg_order, 1)
+  expect_equal(stmarpars_to_gstmar(2, 1, pars21tcr, restricted=TRUE, constraints=R3, maxdf=4)$params, c(1, 0.1, 1))
+})
